==> haskell-primes-0.2.1.0-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-primes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 primes
version:              0.2.1.0
visibility:           public
id:                   primes-0.2.1.0-4FlmqGEB4JCDXui124fQpB
key:                  primes-0.2.1.0-4FlmqGEB4JCDXui124fQpB
license:              BSD-3-Clause
maintainer:           Sebastian Fischer
author:               Sebastian Fischer
stability:            experimental
homepage:             http://github.com/sebfisch/primes
synopsis:             Efficient, purely functional generation of prime numbers
description:
    This Haskell library provides an efficient lazy wheel sieve for
    prime generation inspired by /Lazy wheel sieves and spirals of/
    /primes/ by Colin Runciman and /The Genuine Sieve of Eratosthenes/
    by Melissa O'\''Neil.

category:             Algorithms, Numerical
abi:                  5e3787c93597b91fc5ab2361721f6f16
exposed:              True
exposed-modules:      Data.Numbers.Primes
import-dirs:          /usr/lib/ghc-9.2.8/site-local/primes-0.2.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/primes-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primes
hs-libraries:         HSprimes-0.2.1.0-4FlmqGEB4JCDXui124fQpB
depends:              base-4.16.4.0
haddock-interfaces:   /usr/share/doc/haskell-primes/html/primes.haddock
haddock-html:         /usr/share/doc/haskell-primes/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-primes-0.2.1.0-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-primes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 primes
version:              0.2.1.0
visibility:           public
id:                   primes-0.2.1.0-LmLNpOWl018Fc2AFLcapwU
key:                  primes-0.2.1.0-LmLNpOWl018Fc2AFLcapwU
license:              BSD-3-Clause
maintainer:           Sebastian Fischer
author:               Sebastian Fischer
stability:            experimental
homepage:             http://github.com/sebfisch/primes
synopsis:             Efficient, purely functional generation of prime numbers
description:
    This Haskell library provides an efficient lazy wheel sieve for
    prime generation inspired by /Lazy wheel sieves and spirals of/
    /primes/ by Colin Runciman and /The Genuine Sieve of Eratosthenes/
    by Melissa O'\''Neil.

category:             Algorithms, Numerical
abi:                  344c00c1c836c8ebfc1db41f0343c3bc
exposed:              True
exposed-modules:      Data.Numbers.Primes
import-dirs:          /usr/lib/ghc-9.4.8/site-local/primes-0.2.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/primes-0.2.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/primes-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primes
hs-libraries:         HSprimes-0.2.1.0-LmLNpOWl018Fc2AFLcapwU
depends:              base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-primes/html/primes.haddock
haddock-html:         /usr/share/doc/haskell-primes/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
